==> ejc-middlemeasurement-impl-3.0.0-20240327.063749-530-sources.jar: com/ejianc/business/middlemeasurement/mapper/SubcontractingvolumeMapper.java <==
package com.ejianc.business.middlemeasurement.mapper;

import com.ejianc.business.middlemeasurement.vo.SubcontractingvolumedetailVO;
import com.ejianc.foundation.middlemeasurement.vo.SettlementBookMaterialDetailVO;
import com.ejianc.foundation.middlemeasurement.vo.SettlementBookOtherDetailVO;
import com.ejianc.foundation.middlemeasurement.vo.SettlementBookStatementDetailVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumeEntity;
import com.ejianc.business.middlemeasurement.vo.SubcontractaccountPullVO;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;

import java.util.List;
import java.util.Map;

/**
 * 分包月度报量及申请报告
 *
 * @author generator
 *
 */
@Mapper
public interface SubcontractingvolumeMapper extends BaseCrudMapper<SubcontractingvolumeEntity> {
	SubcontractaccountPullVO getSubcontractaccountAmount(@Param("contractId") Long contractId);

	/**
	 * 根据合同id查询以往所有的分包月度报量及申请报告的汇总数据
	 * @param contractId 合同id
	 * @return
	 */
	List<SettlementBookStatementDetailVO> querySubcontractingvolumeDetailByContractId(Long contractId);

	/**
	 * 根据合同id查询以往所有的分包月度报量及申请报告的物资超用扣款明细数据
	 * @param contractId 合同id
	 * @return
	 */
	List<SettlementBookMaterialDetailVO> querySubcontractingvolumeMaterialByContractId(Long contractId);
	/**
	 * 根据合同id查询以往所有的分包月度报量及申请报告的其他扣款数据
	 * @param contractId 合同id
	 * @return
	 */
	List<SettlementBookOtherDetailVO> querySubcontractingvolumeOtherByContractId(Long contractId);
	/***
	 * @Description //TODO
	 * 查询分包月度报量及申请报告明细往期数据
	 * @param map
	 * @return java.util.List<com.ejianc.business.middlemeasurement.vo.SubcontractingvolumedetailVO>
	 * @createDate 2023/2/3
	 * @author yupengjie
	 **/
	List<SubcontractingvolumedetailVO> querySubcontractingvolumedetail(Map<String,String> map);

	List<SubcontractingvolumedetailVO> querySettleBook(Long contractId);
}

==> ejc-middlemeasurement-impl-3.0.0-20240919.082854-614-sources.jar: com/ejianc/business/middlemeasurement/mapper/SubcontractingvolumeMapper.java <==
package com.ejianc.business.middlemeasurement.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.middlemeasurement.vo.ContractSupplierVO;
import com.ejianc.business.middlemeasurement.vo.SubcontractingvolumeVO;
import com.ejianc.business.middlemeasurement.vo.SubcontractingvolumedetailVO;
import com.ejianc.foundation.middlemeasurement.vo.SettlementBookMaterialDetailVO;
import com.ejianc.foundation.middlemeasurement.vo.SettlementBookOtherDetailVO;
import com.ejianc.foundation.middlemeasurement.vo.SettlementBookStatementDetailVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import com.ejianc.business.middlemeasurement.bean.SubcontractingvolumeEntity;
import com.ejianc.business.middlemeasurement.vo.SubcontractaccountPullVO;
import com.ejianc.framework.skeleton.template.BaseCrudMapper;

import java.util.List;
import java.util.Map;

/**
 * 分包月度报量及申请报告
 *
 * @author generator
 *
 */
@Mapper
public interface SubcontractingvolumeMapper extends BaseCrudMapper<SubcontractingvolumeEntity> {
	SubcontractaccountPullVO getSubcontractaccountAmount(@Param("contractId") Long contractId);

	/**
	 * 根据合同id查询以往所有的分包月度报量及申请报告的汇总数据
	 * @param contractId 合同id
	 * @return
	 */
	List<SettlementBookStatementDetailVO> querySubcontractingvolumeDetailByContractId(Long contractId);

	/**
	 * 根据合同id查询以往所有的分包月度报量及申请报告的物资超用扣款明细数据
	 * @param contractId 合同id
	 * @return
	 */
	List<SettlementBookMaterialDetailVO> querySubcontractingvolumeMaterialByContractId(Long contractId);
	/**
	 * 根据合同id查询以往所有的分包月度报量及申请报告的其他扣款数据
	 * @param contractId 合同id
	 * @return
	 */
	List<SettlementBookOtherDetailVO> querySubcontractingvolumeOtherByContractId(Long contractId);
	/***
	 * @Description //TODO
	 * 查询分包月度报量及申请报告明细往期数据
	 * @param map
	 * @return java.util.List<com.ejianc.business.middlemeasurement.vo.SubcontractingvolumedetailVO>
	 * @createDate 2023/2/3
	 * @author yupengjie
	 **/
	List<SubcontractingvolumedetailVO> querySubcontractingvolumedetail(Map<String,String> map);

	List<SubcontractingvolumedetailVO> querySettleBook(Long contractId);

	List<ContractSupplierVO> getContractData(Page<ContractSupplierVO> page, @Param(Constants.WRAPPER) QueryWrapper queryWrapper, @Param("startDate")String startDate, @Param("endDate")String endDate, @Param("projectId")Long projectId);

}
